; ********************************************
; DRIVERS FOR:
;
; Radio Shack DMP-105
; Radio Shack CGP-220
; ********************************************
; 
IF prn_mdl eq MDL_RSDMP105
	;	Radio Shack DMP-105 code
	;
	;	Documentation supplied by:
	;		Mark Wolovetz
	;		3-780 River Rd.
	;		Winnipeg, Manitoba CANADA R2M 5C3

	prn_byte	= byte_vert
	PRN_GR		= GR_BIT
	GR_BIT_VAL	= 080H		; This bit must be set for all gfx data
	prn_chrset	= chrset_other	; Use printer's character set as possible

	;        prn                    (1/10")
	;      # mode  rep rot pattern  x"   y"
	GFXMAP 0,  0,   2,  0,     200, 80, 105
	GFXMAP 1,  0,   1,  0,     200, 80, 105
	GFXMAP 2,  0,   1,  0,     350, 80, 105
	GFXMAP 3,  0,   1,  0,     480, 80, 105
	GFXMAP 4,  0,   1,  0,    HERC, 80, 105
	GFXMAP X,  0,   1,  0,     480, 80, 105
	; No alternates available
	gfxmap_end label word

	;	GMODES: table of printer graphics modes

	GMODES	LABEL	WORD
		PRNMODE	0, 100, 72
	MAXMODE	EQU	0

	;	Graphics Mode definitions.

	PMODE_PRT0	DW	4
			DB	27,16,0,0 ; position print head @ left margin
					; (graphics data follow)
	PMODE_LEN0	DW	800	; (length placed here, ignored)
	GR_OFF	DW	0		; Graphics remain on during printing
	EGADSTR	GSETUP,<27,20,18>	; Enter condensed print, graphics mode
	EGADSTR	NSPACE,<30,27,19>	; Exit graphics mode; 10 cpi

	EGADSTR	CR,<13>			; CR only
	EGADSTR CRLF,<13,10>		; CR/LF pair
	EGADSTR	MLCRLF,<10>		; Graphics linefeed

	;	Text mode, Attribute definitions.

	TEXT_ATTRS LABEL WORD
		DW	text_nor	; 0
		DW	text_bold	; 1
		DW	text_undr	; 2
		DW	text_cond	; 3

	N_TEXT_ATTRS EQU (($-TEXT_ATTRS)/2)-1 ; normally 3

	EGADSTR	TEXT_NOR, <27,19,27,32,14> ; Normal
	EGADSTR TEXT_BOLD,<27,31>	; bold
	EGADSTR TEXT_UNDR,<15>		; underline
	EGADSTR TEXT_COND,<27,20>	; Condensed

	;	DMP-105 bits are LSB on top

	PATTERN	200, 4, 7
		db	00000011b
		db	00001100b
		db	00110000b
		db	01000000b
	PATTERN	HERC, 6, 7
		db	00000001b
		db	00000010b
		db	00001100b
		db	00010000b
		db	00100000b
		db	01000000b
	PATTERN	350, 7, 7
		db	00000001b
		db	00000010b
		db	00000100b
		db	00001000b
		db	00010000b
		db	00100000b
		db	01000000b
	PATTERN	480, 10, 7
		db	00000001b
		db	00000001b
		db	00000010b
		db	00000100b
		db	00001000b
		db	00001000b
		db	00010000b
		db	00100000b
		db	00100000b
		db	01000000b
		db	0		; end of patterns

	;	Up to 800 Bytes across the page
	BUFLEN	EQU	800

	DITHER_LEVELS	EQU 2			; 2 dither levels (ON/OFF only)
	DITHER_WIDTH	EQU 2			; 2 bytes/level
	NDITHERS	EQU 1			; 1 dither table

	DITHER_TABLE LABEL WORD
		DB	0,0
		DB	0FFH,0FFH

	color_xlat label byte
		db	0,1,1,1,1,1,1,1

	ASCII_XLAT LABEL BYTE
		; 8_H: Foreign letters:
		DB	'Cueaa',0A1H,'a',0A2H,'eeeiiiAA'
		; 9_H:
		DB	'EaAooouuyOUc',0A3H,0B0H,'P',0BFH
		; A_H:
		DB	'aiounNao?--',0AEH,0ACH,'!<>'
		; B_H:
		DB	  32,  32,  32,0F5H,0F9H,0F9H,0F9H,0F2H
		DB	0F2H,0F9H,0F5H,0F2H,0F7H,0F7H,0F7H,0F2H
		; C_H:
		DB	0F6H,0F8H,0F3H,0F4H,0F1H,0FAH,0F4H,0F4H
		DB	0F6H,0F0H,0F8H,0F3H,0F4H,0F1H,0FAH,0F8H
		; D_H:
		DB	0F8H,0F3H,0F3H,0F6H,0F6H,0F0H,0F0H,0FAH
		DB	0FAH,0F7H,0F0H,0EFH,0E8H,0E9H,0EAH,0E7H
		; E_H: Greek letters &c:
		DB	  32,0B9H,  32,  32,  32,  32,0A5H,  32
		DB	  32,  32,  32,  32,  32,  32,  32,  32
		; F_H: Math Symbols:
		DB	  32,  32,  32,  32,  32,  32,  32,  32
		DB	0A6H,0A6H,0A6H,  32,  32,  32, '*',  32

	EXT_CHARS LABEL BYTE
		; This code is sent before text printing begins.
		DW	4
		DB	27,21		; CR's don't do LF's!
		DB	27,19		; Normal (10 cpi)

	; End of DMP-105 code
ENDIF

IF prn_mdl eq mdl_RSCGP220
	;	Radio Shack CGP-220 Inkjet

	prn_byte	= byte_horiz
	PRN_GR		= GR_FIX + GR_NOT
	prn_chrset	= chrset_ascii7	; Standard PC-8 -> ASCII

	;	Create GMODES table using GFXMAP macro.

	; Need to check 320x200 mode.  WL 11/13/92


	;        prn                    (1/10")
	;      # mode  rep rot pattern  x"   y"
	GFXMAP 0,  0,   2,  0,     200, 80, 105	; 320x200
	GFXMAP 1,  0,   2,  0,      10, 80, 105	; 640x200
	GFXMAP 2,  0,   1,  1,       6, 80, 105	; 640x350
	GFXMAP 3,  0,   1,  0,       8, 80, 105	; 640x480
	GFXMAP 4,  0,   1,  1,     200, 80, 105	; 720x348
	GFXMAP X,  0,   1,  0,       8, 80, 105
	; Alternates available
	GFXMAP 10, 0,   1,  1,       6, 80, 105	; 320x200
	GFXMAP 11, 0,   1,  1,       3, 80, 105	; 640x200
	GFXMAP 12, 0,   1,  0,      11, 80, 105	; 640x350
	GFXMAP 13, 0,   1,  1,       8, 80, 105	; 640x480
	GFXMAP 14, 0,   1,  1,     200, 80, 105	; 720x348
	GFXMAP 1X, 0,   1,  1,       8, 80, 105
	gfxmap_end label word

	;	Graphics Mode definitions.

	GMODES	LABEL	WORD
		PRNMODE 0, 80, 80
	MAXMODE	EQU	0

	EGADSTR	PMODE_PRT0,<>			; Already In Color Scan Mode
	PMODE_LEN0	DW	80		; 640 dots/line = 80 bytes

	EGADSTR	GR_OFF,<>	; n/a - can change colors in gfx mode.

	; No graphics setup needed
	EGADSTR	GSETUP,<>

	EGADSTR	MLCRLF,<>			; no CR codes needed

	EGADSTR NSPACE,<>

	; Position @ dot 0 (DOES NOT WORK EVEN THO' MANUAL SAYS IT WILL!!!)
	EGADSTR	CR,<27,16,0,0>

	; CR alone does CR & LF functions
	EGADSTR	CRLF,<13>

	;	Graphics bits are MSB on left, 8 bits usable

	PATTERN	200, 5, 8		; 5 dots/print column
		db	11000000b
		db	00100000b
		db	00011000b
		db	00000100b
		db	00000011b
	PATTERN	3, 3, 8			; 3 print dots/column
		db	11100000b
		db	00011000b
		db	00000111b
	PATTERN	6, 6, 8			; 6 print dots/column
		db	11000000b
		db	00100000b
		db	00010000b
		db	00001100b
		db	00000010b
		db	00000001b
	PATTERN	8, 8, 8			; 8 print dots/column
		db	10000000b
		db	01000000b
		db	00100000b
		db	00010000b
		db	00001000b
		db	00000100b
		db	00000010b
		db	00000001b
	PATTERN	10, 10, 8		; 10 print dots/column
		db	10000000b
		db	10000000b
		db	01000000b
		db	00100000b
		db	00010000b
		db	00001000b
		db	00001000b
		db	00000100b
		db	00000010b
		db	00000001b
	PATTERN	11, 11, 8		; 11 print dots/column
		db	10000000b
		db	10000000b
		db	01000000b
		db	00100000b
		db	00010000b
		db	00010000b
		db	00001000b
		db	00000100b
		db	00000010b
		db	00000010b
		db	00000001b
		db	0		; end of patterns

	NBUFFERS EQU 3
	EGADSTR GR_YELLOW <27,67,80>	; Enter color scan mode
	EGADSTR GR_MAGENTA <>		; no code
	EGADSTR GR_CYAN <>		; no code
	
	YELLOW	DW	3
		DB	27,'T3'		; Select yellow ink
	MAGENTA	DW	3
		DB	27,'T5'		; Select magenta ink
	CYAN	DW	3
		DB	27,'T6'		; Select cyan ink
	BLACK	DW	3
		DB	27,'T0'		; Select black ink

	;	Up to 640 Bytes across the page, plus two bytes of length
	BUFLEN	EQU	642

	DITHER_LEVELS	EQU 2			; 2 dither levels (on/off)
	DITHER_WIDTH	EQU 2			; bytes per pattern
	NDITHERS	EQU 1			; 1 dither tables

	DITHER_TABLE LABEL WORD
		DB	   0,   0	; 0-Level Dither
		DB	   0FFH,0FFH	; 1

	color_xlat label byte
		db	000h,001h,001h,001h,002h,003h,003h,003h
		db	002h,003h,003h,003h,002h,003h,003h,003h
		db	004h,005h,005h,005h,006h,007h,001h,001h
		db	006h,002h,003h,003h,006h,002h,003h,003h
		db	004h,005h,005h,005h,006h,004h,005h,005h
		db	006h,006h,007h,007h,006h,006h,007h,007h
		db	004h,005h,005h,005h,006h,004h,005h,005h
		db	006h,006h,007h,007h,006h,006h,007h,007h

	; End of Radio Shack CGP-220 code
ENDIF
