; ********************************************
; DRIVERS FOR:
;
; Xerox 4020 Inkjet printer
; ********************************************
; 
IF (prn_mdl eq mdl_Xerox4020)
	;
	prn_chrset	= chrset_ascii7
	prn_byte	= byte_horiz
	PRN_GR		= GR_DEC
	GR_DEC_DIGITS	= 3	; digits

	;
	;	GMAP: Table of screen resolutions to printer resolutions.
	;	(** See comment below about REPEAT field on HP printer **)
	;
	;	X & Y are limits of full page enlargement.
	;
	;	Printer Horizontal: Resolution (dpi) * Screen Pixels/Byte
	;		[* 8 inches / 8 bit/bytes -- these cancel]
	;	Printer Vertical: Resolution (dpi) * 10 Inches /
	;		Repeat Factor

	; Primary Setups
	;        prn                    (1/10")
	;      # mode  rep rot pattern  x"   y"
	GFXMAP 0,  0,   2,  0,     5, 80, 105	; 320x200
	GFXMAP 1,  0,   3,  0,     6, 80, 105	; 640x200
	GFXMAP 2,  0,   2,  1,     3, 80, 105	; 640x350
	GFXMAP 3,  0,   1,  0,     8, 80, 105	; 640x480
	GFXMAP 4,  0,   1,  1,     5, 80, 105	; 720x348
	GFXMAP X,  0,   1,  0,     8, 80, 105
	; Secondary Setups
	GFXMAP 10, 0,   2,  1,     3, 80, 105	; 320x200
	GFXMAP 11, 0,   1,  1,     3, 80, 105	; 640x200
	GFXMAP 12, 0,   2,  0,     6, 80, 105	; 640x350
	GFXMAP 13, 0,   2,  1,     4, 80, 105	; 640x480
	GFXMAP 14, 0,   2,  0,     6, 80, 105	; 720x348
	GFXMAP 1X, 0,   1,  1,     8, 80, 105	; Reduce 
	gfxmap_end label word

	;	Graphics Mode definitions.
	;

	; NOTE! For this printer, the third character in the escape
	; sequence depends on which of four scanlines (within one
	; "microline") we are printing!
	EGADSTR GR_YELLOW,<27,'g?'>	; Begin yellow graphics data
	EGADSTR GR_MAGENTA,<27,'g?'>	; Begin magenta graphics data
	EGADSTR GR_CYAN,<27,'g?'>	; Begin cyan graphics data
	EGADSTR GR_BLACK,<27,'g?'>	; Begin black graphics data

	PMODE_PRT0	LABEL WORD
		DW 4
	PMODE_LEN0	LABEL	BYTE
		DB	gr_dec_digits dup (0)	; Count goes here
		DB	32	; space delimiter

	; Graphics resolutions:
	GMODES	LABEL	WORD
		PRNMODE	0, 120, 120
	MAXMODE	EQU	0

	; Sent before graphics mode begins
	EGADSTR GSETUP,<27,13,'P',27,'\',27,'we'>
				; Esc-P   reset printer
				; Esc-\   unidirectional printing
				; Esc-we  set standard graphics mode
				; Esc-wf  set extended graphics mode
	; Sent before text printouts begin
	EGADSTR EXT_CHARS,<27,13,'P',27,'\',27,'wa'>
				; Esc-P   reset printer
				; Esc-\   unidirectional printing
				; Esc-wa  set NLQ text mode

	EGADSTR	NSPACE,<27,'k1'>	; End raster graphics transfer
					; by printing last microline
	EGADSTR GR_OFF,<>		; No end-graphics code

	EGADSTR	CR,<13>			; CR only
	EGADSTR CRLF,<13,10>		; CR/LF pair
	EGADSTR MLCRLF,<>		; Sent after each scanline
	EGADSTR MLXCRLF,<27,'k1'>	; Print 4 scanlines (1 microline)
					; and advance

	;	Text mode, Attribute definitions.
	;	Treat colors like text attributes.

	TEXT_ATTRS LABEL WORD
		DW	T_BLACK		; 0
		DW	T_YELLOW	; 1
		DW	T_MAGENTA	; 2
		DW	T_RED		; 3
		DW	T_CYAN		; 4
		DW	T_GREEN		; 5
		DW	T_BLUE		; 6
		DW	T_WHITE		; 7

	N_TEXT_ATTRS EQU (($-TEXT_ATTRS)/2)-1 ; should be 7

	EGADSTR T_WHITE,   <27,'@01'>	; White characters on black bkg.
	EGADSTR T_BLACK,   <27,'@10'>	; Black characters on white
	EGADSTR T_MAGENTA, <27,'@20'>
	EGADSTR T_RED,     <27,'@30'>
	EGADSTR T_YELLOW,  <27,'@40'>
	EGADSTR T_GREEN,   <27,'@50'>
	EGADSTR T_CYAN,    <27,'@60'>
	EGADSTR T_BLUE,    <27,'@70'>

	NBUFFERS	EQU 4		; C/M/Y/K

	;	The MSB is on the left of each byte.

	PATTERN	3, 3, 8		; 3 Screen Lines per print column
	PATTERN_200 EQU PATTERN_3
		db	11000000b
		db	00111000b
		db	00000111b
	PATTERN 4, 4, 8		; 4 Screen Lines per print column
		db	11000000b
		db	00110000b
		db	00001100b
		db	00000011b
	PATTERN	5, 5, 8		; 5 Screen Lines per print column
		db	10000000b
		db	01100000b
		db	00011000b
		db	00000100b
		db	00000011b
	PATTERN	6, 6, 8		; 6 Screen Lines per print column
		db	10000000b
		db	01100000b
		db	00010000b
		db	00001000b
		db	00000110b
		db	00000001b
	PATTERN 8, 8, 8
		db	10000000b
		db	01000000b
		db	00100000b
		db	00010000b
		db	00001000b
		db	00000100b
		db	00000010b
		db	00000001b
		db	0		; end of patterns

	; Page print width is eight inches. Maximum dot density is
	; RESX0. 8 Bits/Byte. Maximum buffer size RESX0, plus 2 bytes length.
	BUFLEN	EQU	RESX0 + 2

	; 4 Dither levels, but 2 dither tables (entries taken from
	; the B&W printer's dither tables.)
	DITHER_LEVELS	EQU 4			; # of dither patterns
	DITHER_WIDTH	EQU 1			; 1 byte per level
	NDITHERS	EQU 4			; 4 dither tables

	DITHER_TABLE LABEL WORD
		DB	000H,022H,055H,0FFH	; 1st line
		DB	000H,011H,0AAH,0FFH	; 2nd line
		DB	000H,044H,055H,0FFH	; 3rd line
		DB	000H,088H,0AAH,0FFH	; 4th line

	; Translate abstract colors	(--yymmcc)
	;    to physical ones		(kkccmmyy)
	COLOR_XLAT LABEL BYTE
		db	000h,010h,020h,030h,004h,014h,024h,034h
		db	008h,018h,028h,038h,00Ch,01Ch,02Ch,03Ch
		db	001h,011h,021h,031h,005h,040h,025h,035h
		db	009h,019h,029h,039h,00Dh,01Dh,02Dh,03Dh
		db	002h,012h,022h,032h,006h,016h,026h,036h
		db	00Ah,01Ah,080h,03Ah,00Eh,01Eh,02Eh,03Eh
		db	003h,013h,023h,033h,007h,017h,027h,037h
		db	00Bh,01Bh,02Bh,03Bh,00Fh,01Fh,02Fh,0C0h

	; End of Xerox 4020 code
ENDIF
